@@ -18,7 +18,14 @@
  * USA.
  */ 
 
-import java.awt.*;
+import java.awt.BorderLayout;
+import java.awt.GridLayout;
+import java.awt.Dimension;
+import java.awt.Color;
+import java.awt.Point;
+import java.awt.Container;
+import java.awt.Component;
+import java.awt.Toolkit;
 import java.awt.event.*;
 import javax.swing.*;
 import javax.swing.border.*;
