@@ -24,9 +24,7 @@ import java.net.URL;
 import java.util.Iterator;
 import java.util.List;
 import org.jdesktop.jdic.filetypes.internal.AppAssociationWriter;
-import org.jdesktop.jdic.filetypes.internal.AppAssociationWriterFactory;
 import org.jdesktop.jdic.filetypes.internal.AppAssociationReader;
-import org.jdesktop.jdic.filetypes.internal.AppAssociationReaderFactory;
 import org.jdesktop.jdic.filetypes.internal.AppUtility;
 import org.jdesktop.jdic.init.JdicInitException;
 import org.jdesktop.jdic.init.JdicManager;
@@ -59,24 +57,33 @@ public class AssociationService {
     // A platform-dependent instance of AppAssociationWriter.
     private AppAssociationWriter appAssocWriter;
   
-    // Add the initialization code from package org.jdesktop.jdic.init.
-    // To set the environment variables or initialize the set up for 
-    // native libraries and executable files.
-    static {
-        try {
-            JdicManager jm = JdicManager.getManager();
-            jm.initShareNative();
-        } catch (JdicInitException e){
-            e.printStackTrace();
-        }
-    }
-
+    static java.lang.reflect.Method mdAppAssociationReaderFactory_newInstance = null;
+    static java.lang.reflect.Method mdAppAssociationWriterFactory_newInstance = null;
+    
     /**
      * Constructor of an <code>AssociationService</code> object.
      */
     public AssociationService() {
-        appAssocReader = AppAssociationReaderFactory.newInstance();
-        appAssocWriter = AppAssociationWriterFactory.newInstance();
+        //appAssocReader = AppAssociationReaderFactory.newInstance();
+        //appAssocWriter = AppAssociationWriterFactory.newInstance();
+        try{
+            if(null==mdAppAssociationReaderFactory_newInstance){           
+                mdAppAssociationReaderFactory_newInstance = ClassLoader
+                    .getSystemClassLoader()
+                    .loadClass("org.jdesktop.jdic.filetypes.internal.AppAssociationReaderFactory_"
+                        + JdicManager.getPlatformSuffix() )
+                    .getMethod("newInstance", null);
+                mdAppAssociationWriterFactory_newInstance = ClassLoader
+                    .getSystemClassLoader()
+                    .loadClass("org.jdesktop.jdic.filetypes.internal.AppAssociationWriterFactory_"
+                        + JdicManager.getPlatformSuffix() )
+                    .getMethod("newInstance", null);
+            }        
+            appAssocReader = (AppAssociationReader)mdAppAssociationReaderFactory_newInstance.invoke(null, null);
+            appAssocWriter = (AppAssociationWriter)mdAppAssociationWriterFactory_newInstance.invoke(null, null);
+        }catch(Exception e){
+            e.printStackTrace();
+        }
     }
   
     /**
