@@ -71,6 +71,9 @@ PRLock *gMsgLock;
 // the array of browser windows currently open
 WBArray gBrowserArray;
 
+//cached url for post
+char gCachedURL[1024];
+
 // the new event source for socket message
 #ifdef MOZ_WIDGET_GTK
 static GSourceFuncs event_funcs = {
@@ -329,8 +332,7 @@ set_browser_visibility (GtkBrowser *browser, gboolean visibility)
 }
 
 void
-OpenURL(GtkBrowser *pBrowser, const char *pUrl, 
-        const char *pPostData, const char *pHeader)
+OpenURL(GtkBrowser *pBrowser, const char *pUrl, const char *pPostData, const char *pHeader)
 {
     nsresult rv;
     nsCOMPtr<nsIInputStream> postDataStream;
@@ -346,8 +348,7 @@ OpenURL(GtkBrowser *pBrowser, const char *pUrl,
             unsigned long nSizeCL = strlen(szCL);
             unsigned long nSize = nSizeCL + nSizeData;
 
-            // byte stream owns this mem
-            char *tmp = (char *) nsMemory::Alloc(nSize + 1); 
+            char *tmp = (char *) nsMemory::Alloc(nSize + 1); // byte stream owns this mem
             if (tmp) 
             {
                 memcpy(tmp, szCL, nSizeCL);
@@ -376,8 +377,7 @@ OpenURL(GtkBrowser *pBrowser, const char *pUrl,
         unsigned long nSize = strlen(pHeader) + 1;
         if (nSize > 0) 
         {
-            // byteArray stream owns this mem
-            char *tmp = (char *) nsMemory::Alloc(nSize); 
+            char *tmp = (char *) nsMemory::Alloc(nSize); // byteArray stream owns this mem
             if (tmp) 
             {
                 memcpy(tmp, pHeader, nSize);
@@ -400,8 +400,7 @@ OpenURL(GtkBrowser *pBrowser, const char *pUrl,
     }
 
     nsCOMPtr<nsIWebBrowser> webBrowser;
-    gtk_moz_embed_get_nsIWebBrowser(GTK_MOZ_EMBED(pBrowser->mozEmbed), 
-                                    getter_AddRefs(webBrowser));
+    gtk_moz_embed_get_nsIWebBrowser(GTK_MOZ_EMBED(pBrowser->mozEmbed), getter_AddRefs(webBrowser));
     nsCOMPtr<nsIWebNavigation> webNavigation(do_QueryInterface(webBrowser));
     if (!webNavigation)
         return;
@@ -442,8 +441,7 @@ HandleSocketMessage(gpointer data, gpointer user_data)
     case JEVENT_CREATEWINDOW:
         {
             // only create new browser window when the instance does not exist
-            if (instance < gBrowserArray.GetSize() 
-                && gBrowserArray[instance] != NULL)
+            if (instance < gBrowserArray.GetSize() && gBrowserArray[instance] != NULL)
                 break;
             if (i != 3)
                 break;
@@ -453,8 +451,7 @@ HandleSocketMessage(gpointer data, gpointer user_data)
             pBrowser->topLevelWindow = gtk_plug_new(javaXId);
             pBrowser->mozEmbed = gtk_moz_embed_new();
             if (pBrowser->mozEmbed) {
-                gtk_container_add(GTK_CONTAINER(pBrowser->topLevelWindow), 
-                                  pBrowser->mozEmbed);
+                gtk_container_add(GTK_CONTAINER(pBrowser->topLevelWindow), pBrowser->mozEmbed);
                 install_mozembed_cb(pBrowser);
                 gtk_moz_embed_set_chrome_mask(GTK_MOZ_EMBED(pBrowser->mozEmbed),
                     GTK_MOZ_EMBED_FLAG_DEFAULTCHROME);
@@ -502,28 +499,12 @@ HandleSocketMessage(gpointer data, gpointer user_data)
         break;
     case JEVENT_NAVIGATE_POST:
         NS_ASSERTION(i == 3, "Wrong message format\n");
-
-        // Parse the post fields including url, post data and headers.
-        char urlBuf[1024], postDataBuf[1024], headersBuf[1024];
-        memset(urlBuf, '\0', 1024);
-        memset(postDataBuf, '\0', 1024);
-        memset(headersBuf, '\0', 1024);
-
-        ParsePostFields(mMsgString, instance, type, 
-                        urlBuf, postDataBuf, headersBuf);
-
-        char tmpHeadersBuf[2048];
-        memset(tmpHeadersBuf, '\0', 2048);
-        strcpy(tmpHeadersBuf, POST_HEADER);
-        if (strlen(headersBuf) != 0) {
-            strcat(tmpHeadersBuf, headersBuf);
-        }
-
-        char* postDataParam;
-        postDataParam = (strlen(postDataBuf) == 0) ? NULL : postDataBuf;
-
+        strncpy(gCachedURL, mMsgString, sizeof(gCachedURL));
+        break;
+    case JEVENT_NAVIGATE_POSTDATA:
+        NS_ASSERTION(i == 3, "Wrong message format\n");
         pBrowser = (GtkBrowser *)gBrowserArray[instance];
-        OpenURL(pBrowser, urlBuf, postDataParam, tmpHeadersBuf);
+        OpenURL(pBrowser, gCachedURL, mMsgString, POST_HEADER);
         break;
     case JEVENT_GOBACK:
         pBrowser = (GtkBrowser *)gBrowserArray[instance];
@@ -538,8 +519,7 @@ HandleSocketMessage(gpointer data, gpointer user_data)
     case JEVENT_REFRESH:
         pBrowser = (GtkBrowser *)gBrowserArray[instance];
         NS_ASSERTION(pBrowser, "Can't get native browser instance\n");
-        gtk_moz_embed_reload(GTK_MOZ_EMBED(pBrowser->mozEmbed), 
-                             GTK_MOZ_EMBED_FLAG_RELOADNORMAL);
+        gtk_moz_embed_reload(GTK_MOZ_EMBED(pBrowser->mozEmbed), GTK_MOZ_EMBED_FLAG_RELOADNORMAL);
         break;
     case JEVENT_STOP:
         pBrowser = (GtkBrowser *)gBrowserArray[instance];
@@ -551,8 +531,7 @@ HandleSocketMessage(gpointer data, gpointer user_data)
             pBrowser = (GtkBrowser *)gBrowserArray[instance];
             NS_ASSERTION(pBrowser, "Can't get native browser instance\n");
             nsCOMPtr<nsIWebBrowser> webBrowser;
-            gtk_moz_embed_get_nsIWebBrowser(GTK_MOZ_EMBED(pBrowser->mozEmbed), 
-                                            getter_AddRefs(webBrowser));
+            gtk_moz_embed_get_nsIWebBrowser(GTK_MOZ_EMBED(pBrowser->mozEmbed), getter_AddRefs(webBrowser));
             nsCOMPtr<nsIWebNavigation> webNavigation(do_QueryInterface(webBrowser));
             nsCOMPtr<nsIURI> currentURI;
             webNavigation->GetCurrentURI(getter_AddRefs(currentURI));
@@ -580,8 +559,7 @@ HandleSocketMessage(gpointer data, gpointer user_data)
             GtkWidget *widget = GTK_WIDGET (pBrowser->topLevelWindow);
             GdkEvent event;
 
-            GtkWindowClass *parent_class 
-                = (GtkWindowClass*) gtk_type_class (GTK_TYPE_WINDOW);
+            GtkWindowClass *parent_class = (GtkWindowClass*) gtk_type_class (GTK_TYPE_WINDOW);
 
             if (!widget) {
                 ReportError("Failed to get browser's toplevel window !\n");
